@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -198,6 +198,7 @@ BEGIN {
 					}
 					my $initial = $META{$caller};
 					my $merge = $PRO{clone}($META{$with});
+					push @{$merge->{with}}, $merge->{name};
 					$merge->{name} = $initial->{name};
 					$merge->{locked} = $initial->{locked};
 					for my $prop (keys %{$initial->{properties}}) {
@@ -238,6 +239,7 @@ BEGIN {
 					}
 					my $initial = $META{$caller};
 					my $merge = $PRO{clone}($META{$extend});
+					push @{$merge->{extends}}, $merge->{name};
 					$merge->{name} = $initial->{name};
 					$merge->{locked} = $initial->{locked};
 					for my $prop (keys %{$initial->{properties}}) {
@@ -429,7 +431,7 @@ sub get_initialised {
 
 sub get_meta {
 	my ($self, $caller) = @_;
-	return $META{$caller || ref $self};
+	return $PRO{clone}($META{$caller || ref $self});
 }
 
 1;
@@ -442,7 +444,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
@@ -787,7 +789,7 @@ This returns the existing META definition for an object.
 
 	Rope->get_meta('Knot');
 
-NOTE: this may change to clone the hash so that it becomes readonly, but for now it can be used to extend a meta definition if you wish.
+NOTE: this is now read only
 
 =head1 OBJECT CLASS DEFINITION
 
