@@ -121,9 +121,11 @@ sub FETCH {
         my ($self, $key) = @_;
         my $k = $self->{properties}->{$key};
 	return undef unless defined $k->{value};
-	my $caller = $self->current_caller;
-	if ($k->{private} && $caller ne $self->{name}) {
-		die "Cannot access Object ($self->{name}) property ($key) as it is private";
+	if ($k->{private}) {
+		my $priv = $self->private_names;
+		if ( $self->current_caller !~ m/^($priv)$/) {
+			die "Cannot access Object ($self->{name}) property ($key) as it is private";
+		}
 	}
 	if (!$k->{writeable} && !$k->{configurable} && (ref($k->{value}) || '') eq 'CODE') {
 		if ($k->{before} || $k->{after} || $k->{around}) {
@@ -181,12 +183,18 @@ sub SCALAR {
 
 sub DESTROY { }
 
+sub private_names {
+	my $self = shift;
+	return $self->{name} . ($self->{with} ? ('|' . join('|', @{$self->{with}})) : '') . ($self->{extends} ? ('|' . join('|', @{$self->{extends}})) : ''); 
+}
+
 sub current_caller {
-	for (qw/0 1 2 3 4 5/) {
-		my $call = scalar caller($_);
-		if ($call !~ m/Rope::(Object|Autoload|Monkey)/) {
+	my ($n, $caller) = (0, '');
+	while (my $call = scalar caller($n)) {
+		if ($call !~ m/Rope(::(Object|Autoload|Monkey))?/) {
 			return $call;
 		}
+		$n++;
 	}
 }
 
